mlpy.deploy package
===================

.. automodule:: mlpy.deploy
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

.. toctree::
   :maxdepth: 4

   mlpy.deploy.api
   mlpy.deploy.cli
   mlpy.deploy.client
   mlpy.deploy.schemas
